# PyhtonServiceUtil
A service Util for Python Based Micro Services  with support for REST Interservice calls , AWS SQS , Redis and MongoDB.
 1007  pip install -r  requirements.dev.txt
 1008  ls
 1009  python setup.py bdist_wheel sdist
 1010  twine check dist/*
 1011  twine upload dist/*